@@ -57,6 +57,7 @@ public:
 	QString sMidiBankSelect;
 	int     iMidiChannels;
 	QString sMidiName;
+	bool    bMidiAutoConnect;
 	QString sAudioDriver;
 	QString sAudioDevice;
 	QString sJackName;
@@ -68,6 +69,7 @@ public:
 	int     iAudioBufCount;
 	QString sSampleFormat;
 	float   fSampleRate;
+    bool    bWasapiExclusive;
 	int     iPolyphony;
 	bool    bReverbActive;
 	double  fReverbRoom;
